@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2014 Ricardo Villalba <rvm@users.sourceforge.net>
     Copyright (C) 2010 Ori Rejwan
 
     This program is free software; you can redistribute it and/or modify
@@ -40,7 +40,7 @@ QObject(parent), speed(0)
 
 void DownloadFile::getRequest(QString url)
 {
-        QUrl realUrl = QUrl::fromEncoded(url.toAscii(), QUrl::StrictMode);
+        QUrl realUrl = QUrl::fromEncoded(url.toLatin1(), QUrl::StrictMode);
         getRequest(realUrl);
 }
 
@@ -64,7 +64,9 @@ void DownloadFile::downloaded(qint64 bytesReceived, qint64 total)
         static unsigned int count = 0;
         count++;
 
-        if (count % 50 == 0) 
+        #if QT_VERSION < 0x050000
+        if (count % 50 == 0)
+        #endif
         {
             totalSize = total;
             completed = bytesReceived;
@@ -207,10 +209,6 @@ void DownloadFile::emitError(QNetworkReply::NetworkError error)
                 file->close();
                 emit errorOcurred((int)error);
         }
-        /*
-        else
-                qDebug() << "Hello Darling";
-        */
 }
 
 #include "moc_downloadfile.cpp"
