@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2014 Ricardo Villalba <rvm@users.sourceforge.net>
     Copyright (C) 2010 Ori Rejwan
 
     This program is free software; you can redistribute it and/or modify
@@ -17,7 +17,12 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#ifdef USE_SINGLE_APPLICATION
 #include "QtSingleApplication"
+#else
+#include <QApplication>
+#endif
+
 #include <QTranslator>
 #include <QLibraryInfo>
 #include <QSettings>
@@ -84,7 +89,11 @@ QString qtTranslationsPath() {
 
 int main( int argc, char ** argv ) 
 {
+#ifdef USE_SINGLE_APPLICATION
 	QtSingleApplication a("smtube", argc, argv);
+#else
+	QApplication a(argc, argv);
+#endif
 	/* a.setWheelScrollLines(1); */
 
 	QString search_term;
@@ -103,6 +112,7 @@ int main( int argc, char ** argv )
 		search_term = args[n];
 	}
 
+#ifdef USE_SINGLE_APPLICATION
 	QString message;
 	if (!search_term.isEmpty()) message = "search " + search_term;
 	if (a.isRunning()) { 
@@ -110,6 +120,7 @@ int main( int argc, char ** argv )
 		qDebug("Another instance is running. Exiting.");
 		return 0;
 	}
+#endif
 	a.connect( &a, SIGNAL( lastWindowClosed() ), &a, SLOT( quit() ) );
 
 	QString locale = QLocale::system().name();
@@ -133,17 +144,18 @@ int main( int argc, char ** argv )
 	YTDialog * yt = new YTDialog(0, &settings);
 
 #ifdef YT_USE_SCRIPT
-	QString ytcode_name = "ytcode.script";
+	QString ytcode_name = "yt.js";
 	QString ytcode_file = configPath() +"/"+ ytcode_name;
 	if (QFile::exists(smplayerConfigPath())) ytcode_file = smplayerConfigPath() +"/"+ ytcode_name;
 	qDebug("ytcode_file: %s", ytcode_file.toUtf8().constData());
 	yt->setScriptFile(ytcode_file);
 #endif
 
+#ifdef USE_SINGLE_APPLICATION
 	QObject::connect(&a, SIGNAL(messageReceived(const QString&)),
                      yt, SLOT(handleMessage(const QString&)));
-
 	a.setActivationWindow(yt);
+#endif
 
 	if (!search_term.isEmpty()) {
 		yt->setSearchTerm(search_term);
