@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2014 Ricardo Villalba <rvm@users.sourceforge.net>
     Copyright (C) 2010 Ori Rejwan
 
     This program is free software; you can redistribute it and/or modify
@@ -44,6 +44,10 @@
 /* #include "helper.h" */
 #include "myborder.h"
 
+#ifdef Q_WS_AMIGA // zzd10h
+#include <QProcess>
+#endif
+
 RecordingDelegate::RecordingDelegate(QObject *parent)
     :QStyledItemDelegate(parent), selectedBrush(QPixmap(":/Control/bg-download-active.png"))
 {
@@ -52,7 +56,7 @@ RecordingDelegate::RecordingDelegate(QObject *parent)
     QPixmap retryPix(":/Control/bt-download-retry.png");
     playIcon = getIcon(playPix);
     cancelIcon = getIcon(cancelPix);
-    retryIcon = getIcon(retryPix);    
+    retryIcon = getIcon(retryPix);
 }
 
 void RecordingDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
@@ -101,7 +105,7 @@ void RecordingDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
         painter->drawText(QRect(13, optionProgress.rect.bottom() + 3, rect.width(), rect.height()), Qt::AlignLeft | Qt::AlignTop, dd->downloadProgress);
     }
     else if(dd->downloadState == DownloadData::Canceled || dd->downloadState == DownloadData::Error)
-    {        
+    {
         QDateTime time = dd->completionTime;
         QString currentDateString;
         if(time.date() == QDate::currentDate())
@@ -118,7 +122,7 @@ void RecordingDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
                                 headerTextRect.height()), Qt::AlignVCenter | Qt::AlignRight, currentDateString );
         painter->drawText(QRect(headerTextRect.left(), headerTextRect.bottom() + 5, rect.width(), rect.height()),
                           Qt::AlignLeft | Qt::AlignTop, dd->downloadState == DownloadData::Canceled ? tr("Canceled") : tr("Error"));
-        currentPix = retryIcon.pixmap(dd->buttonState, MyIcon::Off );
+        currentPix = retryIcon.pixmap(dd->retry_possible ? dd->buttonState : MyIcon::Disabled, MyIcon::Off );
         QRect buttonRect(rect.width() - 13 - currentPix.width(), headerTextRect.bottom() + 5, currentPix.width(), currentPix.height());
         if(dd->buttonRect != buttonRect) dd->buttonRect = buttonRect;
         painter->drawPixmap(buttonRect, currentPix);
@@ -182,7 +186,7 @@ MyIcon RecordingDelegate::getIcon(QPixmap pix)
     return icon;
 }
 
-QSize RecordingDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
+QSize RecordingDelegate::sizeHint(const QStyleOptionViewItem & /*option*/, const QModelIndex &index) const
 {
     DownloadData* dd = index.data(RecordingDialog::DownloadDataRole).value<DownloadData*>();
     if(dd->downloadState == DownloadData::Progressing)
@@ -252,24 +256,94 @@ void RecordingDialog::downloadVideoId(QString videoId, QString title, double)
     RetrieveVideoUrl* rvu = new RetrieveVideoUrl(this);
     rvu->setPreferredQuality((RetrieveYoutubeUrl::Quality) recording_quality);
     connect(rvu, SIGNAL(signatureNotFound(const QString &)), this, SIGNAL(signatureNotFound(const QString &)));
-    connect(rvu, SIGNAL(gotPreferredUrl(const QString &, QString, QString)), this, SLOT(recordVideo(const QString &,QString,QString)));
-    connect(rvu, SIGNAL(gotPreferredUrl(const QString &, QString, QString)), rvu, SLOT(deleteLater()));
+    connect(rvu, SIGNAL(gotUrls(const QMap<int, QString>&, QString, QString)), this, SLOT(recordVideo(const QMap<int, QString>&, QString, QString)));
+    connect(rvu, SIGNAL(gotUrls(const QMap<int, QString>&, QString, QString)), rvu, SLOT(deleteLater()));
     rvu->fetchYTVideoPage(videoId, title);
 
     if(!isVisible()) show();
 }
 
-void RecordingDialog::recordVideo(const QString & url, QString title, QString id)
-{
-    if(url.isNull())
-    {
-        QMessageBox::warning(0, tr("Recording failed"), tr("There was an error in retrieving the download URL."));
-        return;
-    }
-    download(url, title, id, 0);
+void RecordingDialog::downloadAudioId(QString videoId, QString title, double) {
+	qDebug("RecordingDialog::downloadAudioId");
+
+    RetrieveVideoUrl* rvu = new RetrieveVideoUrl(this);
+    rvu->setPreferredQuality((RetrieveYoutubeUrl::Quality) recording_quality);
+    connect(rvu, SIGNAL(signatureNotFound(const QString &)), this, SIGNAL(signatureNotFound(const QString &)));
+    connect(rvu, SIGNAL(gotUrls(const QMap<int, QString>&, QString, QString)), this, SLOT(recordAudio(const QMap<int, QString>&, QString, QString)));
+    connect(rvu, SIGNAL(gotUrls(const QMap<int, QString>&, QString, QString)), rvu, SLOT(deleteLater()));
+    rvu->fetchYTVideoPage(videoId, title);
+
+    if(!isVisible()) show();
 }
 
-void RecordingDialog::download(QString url, QString title, QString id, double duration)
+void RecordingDialog::recordVideo(const QMap<int, QString>& map, QString title, QString id) {
+	qDebug("RecordingDialog::recordVideo");
+
+	if (recording_quality == RetrieveYoutubeUrl::MP4_1080p || recording_quality == RetrieveYoutubeUrl::WEBM_1080p) {
+		if (!map.contains(RetrieveYoutubeUrl::MP4_1080p) && !map.contains(RetrieveYoutubeUrl::WEBM_1080p)) {
+			qDebug("RecordingDialog::recordVideo: 1080p not found in normal format");
+			// Check if there's a 1080p in DASH format
+			QString video_url = map.value(RetrieveYoutubeUrl::DASH_VIDEO_1080p, QString());
+			QString audio_url = RetrieveYoutubeUrl::findBestAudio(map);
+			if (!video_url.isEmpty() && !audio_url.isEmpty()) {
+				video_url += "&ratebypass=yes";
+				audio_url += "&ratebypass=yes";
+
+				//qDebug("RecordingDialog::recordVideo: video_url: %s", video_url.toLatin1().constData());
+				//qDebug("RecordingDialog::recordVideo: audio_url: %s", audio_url.toLatin1().constData());
+
+				qDebug("RecordingDialog::recordVideo: video and audio for 1080p DASH format found");
+				QString video_name = getUniqueFileName(title +".mp4");
+				qDebug("RecordingDialog::recordVideo: video name '%s'", video_name.toUtf8().constData());
+
+				QString audio_extension = ".m4a";
+				QRegExp rx("itag=(\\d+)");
+				if (rx.indexIn(audio_url) != -1) {
+					int itag = rx.cap(1).toInt();
+					//qDebug("itag: %d", itag);
+					if ((itag == RetrieveYoutubeUrl::DASH_AUDIO_WEBM_128) || (itag == RetrieveYoutubeUrl::DASH_AUDIO_WEBM_192)) {
+						audio_extension = ".webm";
+					}
+				}
+
+				QFileInfo fi(video_name);
+				QString audio_name = fi.absolutePath() +"/"+ fi.completeBaseName() + audio_extension;
+				qDebug("RecordingDialog::recordVideo: audio name '%s'", audio_name.toUtf8().constData());
+
+				if (QFile::exists(audio_name)) {
+					qDebug("RecordingDialog::recordVideo: the audio file already exists. Skipping.");
+				} else {
+					download(audio_url, title, id, 0, audio_name, false);
+				}
+				download(video_url, title, id, 0, video_name, false);
+				return;
+			}
+		}
+	}
+
+	QString url = RetrieveYoutubeUrl::findPreferredUrl(map, (RetrieveYoutubeUrl::Quality) recording_quality);
+	if (url.isEmpty()) {
+		QMessageBox::warning(0, tr("Recording failed"), tr("There was an error in retrieving the download URL."));
+		return;
+	}
+	download(url, title, id, 0);
+}
+
+void RecordingDialog::recordAudio(const QMap<int, QString>& map, QString title, QString id) {
+	qDebug("RecordingDialog::recordAudio");
+
+	QString url = RetrieveYoutubeUrl::findBestAudio(map);
+	url += "&ratebypass=yes";
+
+	if (url.isEmpty()) {
+		QMessageBox::warning(0, tr("Recording failed"), tr("There was an error in retrieving the download URL."));
+		return;
+	}
+
+	download(url, title, id, 0, QString::null, false);
+}
+
+void RecordingDialog::download(QString url, QString title, QString id, double duration, const QString & saveas, bool retry_possible)
 {
     QUrl qurl(url);
     QListWidgetItem* item = new QListWidgetItem(0, QListWidgetItem::UserType + 1);
@@ -298,20 +372,35 @@ void RecordingDialog::download(QString url, QString title, QString id, double du
         case RetrieveYoutubeUrl::WEBM_1080p:
             ext = ".webm";
             break;
+        case RetrieveYoutubeUrl::DASH_AUDIO_MP4_48:
+        case RetrieveYoutubeUrl::DASH_AUDIO_MP4_128:
+        case RetrieveYoutubeUrl::DASH_AUDIO_MP4_256:
+            ext = ".m4a";
+            break;
+        case RetrieveYoutubeUrl::DASH_AUDIO_WEBM_128:
+        case RetrieveYoutubeUrl::DASH_AUDIO_WEBM_192:
+            ext = ".webm";
+            break;
     }
 
-    QFile* file = new QFile(getUniqueFileName(title + ext));
+    QString output_filename = saveas;
+    if (output_filename.isEmpty()) {
+         output_filename = getUniqueFileName(title + ext);
+    }
+
+    QFile* file = new QFile(output_filename);
     dd->title = QFileInfo(*file).fileName();
     dd->filePath = QFileInfo(*file).absoluteFilePath();
     dd->videoDuration = (int)duration;
     dd->downloadProgress = tr("Starting");
     dd->completionTime = QDateTime::currentDateTime();
+    dd->retry_possible = retry_possible;
     item->setData(DownloadDataRole, QVariant::fromValue(dd));
     item->setData(emitDataChangedRole, true);
 
     DownloadFile* dfile = new DownloadFile(url, file, this);
-    file->setParent(dfile);    
-    itemDownloadMap[dfile] = item;    
+    file->setParent(dfile);
+    itemDownloadMap[dfile] = item;
     connect(dfile, SIGNAL(downloadFinished(bool)), this, SLOT(oneDownloadFinished(bool)));
     connect(dfile, SIGNAL(downloadStatus(QString)), this, SLOT(oneDownloadProgressStatus(QString)));
     connect(dfile, SIGNAL(progress(int, qint64)), this, SLOT(oneDownloadProgress(int, qint64)));
@@ -432,7 +521,7 @@ void RecordingDialog::removeDFileFromMap(DownloadFile *dfile)
     updateWindowTitle();
 }
 
-void RecordingDialog::resizeEvent(QResizeEvent *r)
+void RecordingDialog::resizeEvent(QResizeEvent * /*r*/)
 {
     static_cast<RecordingDelegate*>(downloadList->itemDelegate())->setWidth( downloadList->viewport()->width());
 }
@@ -525,7 +614,9 @@ bool RecordingDialog::eventFilter(QObject *watched, QEvent *event)
                     }
                     else if(dd->downloadState == DownloadData::Canceled || dd->downloadState == DownloadData::Error )
                     {
-                        contextMenu.addAction(tr("&Retry"))->setData("retry");
+                        QAction *retryAct = contextMenu.addAction(tr("&Retry"));
+                        retryAct->setData("retry");
+                        if (!dd->retry_possible) retryAct->setEnabled(false);
                         contextMenu.addSeparator();
                         contextMenu.addAction(tr("Remove from &list"))->setData("remove");
                         QAction* action = contextMenu.exec(m->globalPos());
@@ -626,6 +717,9 @@ void RecordingDialog::cancelDownload(QListWidgetItem *item)
 void RecordingDialog::retryDownload(QListWidgetItem *item)
 {
     DownloadData* dd = item->data(DownloadDataRole).value<DownloadData*>();
+
+    if (!dd->retry_possible) return;
+
     dd->downloadState = DownloadData::Progressing;
     dd->downloadProgress = tr("Fetching URL...");
     dd->downloadProgressPercent = 0;
@@ -722,7 +816,7 @@ void RecordingDialog::clearList()
             ++i ;
         }
         else
-        {            
+        {
             delete model->index(i, 0).data(DownloadDataRole).value<DownloadData*>();
             model->removeRow(i);
         }
@@ -761,7 +855,15 @@ void RecordingDialog::videoDoubleClicked(QListWidgetItem *item)
 
 void RecordingDialog::openFolder()
 {
+ #ifdef Q_WS_AMIGA // zzd10h
+    QProcess *process;
+    QString programme = "Amiga/OpenWorkbench.rexx";
+    QStringList argument ;
+    argument << recordings_directory ;
+    process->startDetached(programme,argument);
+ #else
     QDesktopServices::openUrl(QUrl::fromLocalFile(recordings_directory));
+ #endif
 }
 
 void RecordingDialog::saveList()
@@ -783,6 +885,7 @@ void RecordingDialog::saveList()
             ddMap["videoid"] = dd->videoId;
             ddMap["video_duration"] = dd->videoDuration;
             ddMap["title"] = dd->title;
+            ddMap["retry_possible"] = dd->retry_possible;
         }
         itemList.append(ddMap);
     }
@@ -817,6 +920,7 @@ void RecordingDialog::loadList()
         dd->videoDuration = ddMap.value("video_duration").toInt();
         dd->completionTime = ddMap.value("time").toDateTime();
         dd->fileSize = ddMap.value("size").toLongLong();
+        dd->retry_possible = ddMap.value("retry_possible").toBool();
         item->setData(DownloadDataRole, QVariant::fromValue(dd));
         item->setData(emitDataChangedRole, true);
     }
