@@ -23,14 +23,21 @@
 #include <QNetworkReply>
 #include <QMap>
 
+#define YT_GET_VIDEOINFO
+
 class RetrieveYoutubeUrl : public QObject
 {
 	Q_OBJECT
 
 public:
 	enum Quality { FLV_240p = 5, MP4_360p = 18, MP4_720p = 22, FLV_360p = 34,
-                   FLV_480p = 35, MP4_1080p = 37, WEBM_360p = 43, 
-                   WEBM_480p = 44, WEBM_720p = 45, WEBM_1080p = 46 };
+                   FLV_480p = 35, MP4_1080p = 37, WEBM_360p = 43,
+                   WEBM_480p = 44, WEBM_720p = 45, WEBM_1080p = 46,
+                   DASH_AUDIO_MP4_48 = 139, DASH_AUDIO_MP4_128 = 140, DASH_AUDIO_MP4_256 = 141,
+                   DASH_AUDIO_WEBM_128 = 171, DASH_AUDIO_WEBM_192 = 172,
+                   DASH_VIDEO_1080p = 137, DASH_VIDEO_720p = 136,
+                   DASH_VIDEO_480p = 135, DASH_VIDEO_360p = 134,
+                   DASH_VIDEO_240p = 133 };
 
 	RetrieveYoutubeUrl( QObject* parent = 0 );
 	~RetrieveYoutubeUrl();
@@ -38,8 +45,8 @@ public:
 	void fetchPage(const QString & url);
 	void close();
 
-	void setUserAgent(const QString & s) { user_agent = s; };
-	QString userAgent() { return user_agent; };
+	static void setUserAgent(const QString & s) { user_agent = s; };
+	static QString userAgent() { return user_agent; };
 
 	void setPreferredQuality(Quality q) { preferred_quality = q; }
 	Quality preferredQuality() { return preferred_quality; }
@@ -47,10 +54,15 @@ public:
 	static QString findPreferredUrl(const QMap<int, QString>& urlMap, Quality q);
 	QString findPreferredUrl();
 
+	static QString findBestAudio(const QMap<int, QString>& urlMap);
+
 	QString urlTitle() { return url_title; }
 	QString latestPreferredUrl() { return latest_preferred_url; }
 	QString origUrl() { return orig_url; }
 
+	bool isUrlSupported(const QString & url);
+	QString fullUrl(const QString & url);
+
 signals:
 	void gotUrls(const QMap<int, QString>&);
 	void gotPreferredUrl(const QString &);
@@ -62,12 +74,18 @@ signals:
 	void signatureNotFound(const QString & title);
 
 protected slots:
-	void gotResponse(QNetworkReply* reply);
+	void gotResponse();
 	void parse(QByteArray text);
+#ifdef YT_GET_VIDEOINFO
+	void gotVideoInfoResponse();
+	void parseVideoInfo(QByteArray text);
+	void fetchVideoInfoPage();
+#endif
 
 protected:
 	static QString sanitizeForUnicodePoint(QString string);
 	static void htmlDecode(QString& string);
+	QString getVideoID(QString video_url);
 
 	QMap<int, QString> urlMap;
 	QString url_title;
@@ -75,7 +93,11 @@ protected:
 	QString latest_preferred_url;
 
 	Quality preferred_quality;
-	QString user_agent;
+	static QString user_agent;
+
+#ifdef YT_GET_VIDEOINFO
+	QString video_id;
+#endif
 
 private:
 	QNetworkAccessManager* manager;
