@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2014 Ricardo Villalba <rvm@users.sourceforge.net>
     Copyright (C) 2010 Ori Rejwan
 
     This program is free software; you can redistribute it and/or modify
@@ -45,13 +45,23 @@
 #include "searchbox.h"
 #include "recordingdialog.h"
 #include "configdialog.h"
+#include "regions.h"
 #include "about.h"
 
+#if QT_VERSION >= 0x050000
+#include <QStandardPaths>
+#endif
+
 #ifdef YT_USE_SCRIPT
 #include "ytsig.h"
 #include "codedownloader.h"
 #endif
 
+#include "fontpref.h"
+
+int FontPref::base_size = 11;
+
+
 #define PAGE_RESULT_COUNT 25
 
 OverlayWidget::OverlayWidget(QWidget* parent) : QWidget(parent)
@@ -63,13 +73,13 @@ OverlayWidget::OverlayWidget(QWidget* parent) : QWidget(parent)
     timeLine->setFrameRange(1, 13);
     for(int i=0; i < 12; ++i)
     {
-        stages[i] = QPixmap((QString("stage%1").arg(i+1, 2, 10, QChar('0'))));
+        stages[i] = QPixmap((QString(":/icons/stage%1").arg(i+1, 2, 10, QChar('0'))));
     }
     timeLine->setCurveShape(QTimeLine::LinearCurve);
     connect(timeLine, SIGNAL(frameChanged(int)), this, SLOT(frameHasChanged(int)));
 }
 
-void OverlayWidget::paintEvent(QPaintEvent* e)
+void OverlayWidget::paintEvent(QPaintEvent * /*e*/)
 {
     QPainter p(this);
     p.drawPixmap(rect(), loadingOverlay  );
@@ -82,7 +92,7 @@ void OverlayWidget::paintEvent(QPaintEvent* e)
     }
     p.setPen(Qt::white);
     QFont font = p.font();
-    font.setPointSize(12);
+    font.setPixelSize(FontPref::base_size + 1);
     p.setFont(font);
     QRect textRect(0, 0, 280, 40);
     textRect.translate(rect().center() - textRect.center());
@@ -138,19 +148,19 @@ void YTButton::setPix(QPixmap pix)
    setFixedSize(normalPix.size());
 }
 
-void YTButton::enterEvent(QEvent *e)
+void YTButton::enterEvent(QEvent * /*e*/)
 {
     hovered = true;
     update();
 }
 
-void YTButton::leaveEvent(QEvent *e)
+void YTButton::leaveEvent(QEvent * /*e*/)
 {
     hovered = false;
     update();
 }
 
-void YTButton::paintEvent(QPaintEvent *e)
+void YTButton::paintEvent(QPaintEvent * /*e*/)
 {    
     QPainter p(this);
     if(hovered)
@@ -225,7 +235,7 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
     recording_dialog->setRecordingQuality(RetrieveYoutubeUrl::MP4_720p);
 
     MyBorder* border = new MyBorder(this);
-    border ->setBGColor(palette().color(backgroundRole()));
+    border->setBGColor(palette().color(backgroundRole()));
 
     videoList->setFrameShape(QFrame::NoFrame);
     delegate = new YTDelegate(videoList);
@@ -233,7 +243,8 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
     //videoList->setMouseTracking(true);
     //videoList->viewport()->installEventFilter(this);
     videoList->setContextMenuPolicy(Qt::CustomContextMenu);
-    videoList->setAutoScroll(false);
+    //videoList->setAutoScroll(false);
+
     nextButton = new QPushButton(this);
     nextButton->setToolTip(tr("Next"));
     nextButton->setIcon(QPixmap(":/icons/next.png"));
@@ -301,7 +312,8 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
     connect(api, SIGNAL(finalResults(YTReply)), this, SLOT(gotAPIReply(YTReply)));
     connect(pixmap_loader, SIGNAL(pixmapResult(QPixmap,int)), this, SLOT(gotPixmap(QPixmap,int)));
     connect(videoList, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(videoClicked(QListWidgetItem*)));
-    connect(videoList, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(videoDblClicked(QListWidgetItem*)));
+    connect(videoList, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(videoDblClicked(QListWidgetItem*)));
+    connect(videoList, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)), this, SLOT(videoItemChanged(QListWidgetItem*,QListWidgetItem*)));
     connect(videoList, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
 
     connect(recording_dialog, SIGNAL(playFile(QString)), this, SLOT(playVideo(QString)));
@@ -313,10 +325,24 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
             this, SLOT(playYTUrl(QMap<int,QString>,QString, QString)));
     */
 
-    setTabOrder(searchBox, configButton);
+    setTabOrder(searchBox, recordingButton);
+    setTabOrder(recordingButton, configButton);
     setTabOrder(configButton, infoButton);
     setTabOrder(infoButton, prevButton);
     setTabOrder(prevButton, nextButton);
+    setTabOrder(nextButton, tabBar);
+    setTabOrder(tabBar, videoList);
+
+    // Key shortcuts to change the font size
+    QAction * incFontSizeAct = new QAction(this);
+    incFontSizeAct->setShortcut(QKeySequence::ZoomIn);
+    connect(incFontSizeAct, SIGNAL(triggered()), this, SLOT(incFontSize()));
+    addAction(incFontSizeAct);
+
+    QAction * decFontSizeAct = new QAction(this);
+    decFontSizeAct->setShortcut(QKeySequence::ZoomOut);
+    connect(decFontSizeAct, SIGNAL(triggered()), this, SLOT(decFontSize()));
+    addAction(decFontSizeAct);
 
     loadConfig();
 
@@ -345,9 +371,10 @@ YTDialog::~YTDialog()
 		set->endGroup();
 		set->sync();
 	}
+	saveConfig();
 
     delete pixmap_loader;
-    delete recording_dialog; 
+    delete recording_dialog;
 }
 
 void YTDialog::setLoadingOverlay(bool enable)
@@ -366,7 +393,7 @@ void YTDialog::setLoadingOverlay(bool enable)
     }
 }
 
-void YTDialog::resizeEvent(QResizeEvent* r)
+void YTDialog::resizeEvent(QResizeEvent * /*r*/)
 {
     if(overlayVisible)
     {
@@ -375,6 +402,7 @@ void YTDialog::resizeEvent(QResizeEvent* r)
     }
 }
 
+/*
 bool YTDialog::eventFilter(QObject* w, QEvent* e)
 {
     if(w == videoList->viewport())
@@ -412,6 +440,7 @@ bool YTDialog::eventFilter(QObject* w, QEvent* e)
     }
     return false;
 }
+*/
 
 void YTDialog::setMode(Mode mode)
 {
@@ -423,7 +452,7 @@ void YTDialog::setMode(Mode mode)
         searchBox->setText(searchTerm);
         addTab(Popular);
         addTab(Music);
-        addTab(Rated);        
+        addTab(Sport);
     }
     else if(mode == Search)
     {
@@ -458,11 +487,11 @@ void YTDialog::addTab(Tabs tab)
     }
     else if(tab == Music)
     {
-        index = tabBar->addTab(tr("Music Top Rated"));
+        index = tabBar->addTab(tr("Music"));
     }
-    else if(tab == Rated)
+    else if(tab == Sport)
     {
-        index = tabBar->addTab(tr("Most Rated"));
+        index = tabBar->addTab(tr("Sports"));
     }    
     tabBar->setTabData(index, tab);
 }
@@ -474,8 +503,8 @@ void YTDialog::gotCurrentTab(int index)
     switch((int)tab)
     {
     case Popular: setWindowTitle(tr("Most popular videos on YouTube%1").arg(QChar(0x2122)));break;
-    case Rated: setWindowTitle(tr("Most rated videos on YouTube%1").arg(QChar(0x2122)));break;
-    case Music: setWindowTitle(tr("Most rated music videos this week on YouTube%1").arg(QChar(0x2122)));break;
+    case Sport: setWindowTitle(tr("Most popular sport videos on YouTube%1").arg(QChar(0x2122)));break;
+    case Music: setWindowTitle(tr("Most popular music videos on YouTube%1").arg(QChar(0x2122)));break;
     case Relevant :
     case Recent :
     case Viewed : setWindowTitle(tr("YouTube%2 results for \"%1\"").arg(searchTerm).arg(QChar(0x2122)));break;
@@ -491,7 +520,7 @@ void YTDialog::gotCurrentTab(int index)
         switch((int)tab)
         {
         case Popular: resultForTab[api->getMost(Popular)] = Popular; break;
-        case Rated: resultForTab[api->getMost(Rated)]= Rated; break;
+        case Sport: resultForTab[api->getMost(Sport)]= Sport; break;
         case Music: resultForTab[api->getMost(Music)]= Music; break;
         case Relevant : resultForTab[api->getMost(Relevant, searchTerm)]= Relevant; break;
         case Recent : resultForTab[api->getMost(Recent, searchTerm)]= Recent; break;
@@ -665,10 +694,21 @@ void YTDialog::videoClicked(QListWidgetItem *item)
     item->setData(Clicked, true);
 }
 
+void YTDialog::videoItemChanged(QListWidgetItem * current, QListWidgetItem * previous) {
+    //qDebug("YTDialog::videoItemChanged");
+    if (previous) previous->setData(Clicked, false);
+    if (current) current->setData(Clicked, true);
+}
+
 void YTDialog::videoDblClicked(QListWidgetItem *item)
 {
     SingleVideoItem* svi = item->data(0).value<SingleVideoItem*>();
-    if (!players.currentPlayer().directPlay()) {
+#ifdef USE_PLAYERS
+    bool direct_play = players.currentPlayer().directPlay();
+#else
+    bool direct_play = HCPLAYER_DIRECTPLAY;
+#endif
+    if (!direct_play) {
         RetrieveVideoUrl* rvu = new RetrieveVideoUrl(this);
         rvu->setPreferredQuality((RetrieveYoutubeUrl::Quality) playback_quality);
         #ifdef YT_USE_SCRIPT
@@ -692,11 +732,16 @@ void YTDialog::showContextMenu(QPoint point)
     QMenu menu;
     menu.addAction(tr("&Play video"))->setData("play");
     menu.addAction(tr("&Record video"))->setData("record");
+    menu.addAction(tr("R&ecord audio"))->setData("record_audio");
     menu.addAction(tr("&Watch on YouTube"))->setData("watch");
     menu.addAction(tr("&Copy link"))->setData("link");
+ #ifndef Q_WS_AMIGA // zzd10h
+    menu.addAction(tr("&Add URL to the SMPlayer playlist"))->setData("playlist");
+ #endif
 
     QAction* action = menu.exec(videoList->viewport()->mapToGlobal(point));
     if(!action) return;
+
     QListWidgetItem* item = videoList->itemAt(point);
     if(action->data().toString() == "play")
     {
@@ -706,6 +751,10 @@ void YTDialog::showContextMenu(QPoint point)
     {
        recordItem(item);
     }
+    else if(action->data().toString() == "record_audio")
+    {
+       recordAudioItem(item);
+    }
     else if(action->data().toString() == "watch")
     {
         SingleVideoItem* svi = item->data(0).value<SingleVideoItem*>();
@@ -716,6 +765,11 @@ void YTDialog::showContextMenu(QPoint point)
         SingleVideoItem* svi = item->data(0).value<SingleVideoItem*>();
         qApp->clipboard()->setText(QString("http://www.youtube.com/watch?v=%1").arg(svi->videoid));
     }
+    else if(action->data().toString() == "playlist")
+    {
+        SingleVideoItem* svi = item->data(0).value<SingleVideoItem*>();
+        addToPlaylist(QString("http://www.youtube.com/watch?v=%1").arg(svi->videoid));
+    }
 }
 
 void YTDialog::recordItem(QListWidgetItem *item)
@@ -728,22 +782,50 @@ void YTDialog::recordItem(QListWidgetItem *item)
     recording_dialog->downloadVideoId(svi->videoid, svi->header, 0);
 }
 
-void YTDialog::playVideo(QString file) 
+void YTDialog::recordAudioItem(QListWidgetItem *item)
 {
-    QString exec = players.currentPlayer().executable();
-    qDebug("YTDialog::playVideo: command: '%s'", exec.toUtf8().constData());
-    QProcess::startDetached(exec, QStringList() << file);
+    #ifdef YT_USE_SCRIPT
+    YTSig::setScriptFile(script_file);
+    #endif
+
+    SingleVideoItem* svi = item->data(0).value<SingleVideoItem*>();
+    recording_dialog->downloadAudioId(svi->videoid, svi->header, 0);
 }
 
-void YTDialog::playYTUrl(const QString & url, QString title, QString id)
+void YTDialog::playVideo(QString file) 
+{
+#ifdef USE_PLAYERS
+	QString exec = players.currentPlayer().executable();
+#else
+	QString exec = HCPLAYER_EXECUTABLE;
+#endif
+	qDebug("YTDialog::playVideo: command: '%s'", exec.toUtf8().constData());
+
+	QStringList args;
+ #ifdef Q_WS_AMIGA // zzd10h
+	args << "file";
+ #endif
+	args << file;
+	QProcess::startDetached(exec, args);
+}
+
+void YTDialog::playYTUrl(const QString & url, QString title, QString /*id*/)
 {
     qDebug("YTDialog::playYTUrl: title: '%s', url: '%s'", title.toUtf8().constData(), url.toUtf8().constData());
 
+#ifdef USE_PLAYERS
     QString exec = players.currentPlayer().executable();
+    QString title_opt = players.currentPlayer().titleOption();
+#else
+    QString exec = HCPLAYER_EXECUTABLE;
+    QString title_opt = HCPLAYER_TITLEOPTION;
+#endif
     qDebug("YTDialog::playYTUrl: command: '%s'", exec.toUtf8().constData());
     QStringList args;
+ #ifdef Q_WS_AMIGA // zzd10h
+    args << "stream";
+ #endif
     args << url;
-    QString title_opt = players.currentPlayer().titleOption();
     if (!title_opt.isEmpty()) {
         if (title_opt.endsWith(" ")) {
             args << title_opt.left(title_opt.length()-1) << title;
@@ -754,6 +836,34 @@ void YTDialog::playYTUrl(const QString & url, QString title, QString id)
     QProcess::startDetached(exec, args);
 }
 
+void YTDialog::addToPlaylist(const QString &url) {
+	qDebug("YTDialog::addToPlaylist: %s", url.toUtf8().constData());
+
+#ifdef USE_PLAYERS
+	int p = players.findName("SMPlayer");
+	if (p > -1) {
+		QString exec = players.item(p).executable();
+		qDebug("YTDialog::playVideo: command: '%s'", exec.toUtf8().constData());
+
+		QStringList args;
+		args << "-add-to-playlist" << url;
+		QProcess::startDetached(exec, args);
+	} else {
+		qDebug("YTDialog::addToPlaylist: player not found");
+	}
+#else
+	QString exec = HCPLAYER_EXECUTABLE;
+	if (exec.contains("smplayer")) {
+		QStringList args;
+		args << "-add-to-playlist" << url;
+		QProcess::startDetached(exec, args);
+	} else {
+		qDebug("YTDialog::addToPlaylist: smplayer not found");
+	}
+#endif
+}
+
+#ifdef USE_SINGLE_APPLICATION
 void YTDialog::handleMessage(const QString& message)
 {
     qDebug("YTDialog::handleMessage: '%s'", message.toUtf8().constData());
@@ -765,6 +875,7 @@ void YTDialog::handleMessage(const QString& message)
         setSearchTerm(search_term);
     }
 }
+#endif
 
 void YTDialog::showErrorDialog(const QString & error) 
 {
@@ -787,7 +898,7 @@ void YTDialog::showErrorSignatureNotFound(const QString & title) {
 		if (!downloader) downloader = new CodeDownloader(this);
 		downloader->saveAs(script_file);
 		downloader->show();
-		downloader->download(QUrl("http://updates.smplayer.info/ytcode.script"));
+		downloader->download(QUrl("http://updates.smplayer.info/yt.js"));
 	}
 	#else
 	QMessageBox::warning(this, tr("Problems with Youtube"),
@@ -809,8 +920,10 @@ void YTDialog::showConfigDialog()
     ConfigDialog d(this);
     d.setRecordingDirectory(recording_dialog->recordingsDirectory());
     d.setRecordingQuality(recording_dialog->recordingQuality());
+#ifdef USE_PLAYERS
     d.setPlayerNames( players.availablePlayers() );
     d.setPlayer( players.currentPlayer().name() );
+#endif
     d.setPlaybackQuality( playback_quality );
 
     QString period = api->period();
@@ -822,7 +935,11 @@ void YTDialog::showConfigDialog()
     if (d.exec() == QDialog::Accepted) {
         recording_dialog->setRecordingsDirectory(d.recordingDirectory());
         recording_dialog->setRecordingQuality(d.recordingQuality());
-        players.setCurrent( players.findName( d.player() ) );
+        #ifdef USE_PLAYERS
+        int p = players.findName(d.player());
+        if (p == -1) p = 0;
+        players.setCurrent(p);
+        #endif
         playback_quality = d.playbackQuality();
         api->setPeriod( d.period() );
         api->setRegion( d.region() );
@@ -838,13 +955,22 @@ void YTDialog::loadConfig()
 {
     QString recording_directory;
     if (set) {
-        set->beginGroup("general");
+        set->beginGroup("General");
         recording_directory = set->value("recording_directory", recording_dialog->recordingsDirectory()).toString();
         recording_dialog->setRecordingQuality(set->value("record_quality", recording_dialog->recordingQuality()).toInt());
+#ifdef USE_PLAYERS
         players.setCurrent(set->value("player", players.current()).toInt());
-        api->setRegion(set->value("region", "US").toString());
+#endif
+        // Find user's region to be used as default
+        //QLocale locale(QLocale::German, QLocale::Austria); // TEST
+        QLocale locale = QLocale::system();
+        QString local_region = Regions::findRegionForLocale(locale);
+        qDebug("YTDialog::loadConfig: default region: %s", local_region.toUtf8().constData());
+        api->setRegion(set->value("region", local_region).toString());
         api->setPeriod(set->value("period", "today").toString());
         playback_quality = set->value("playback_quality", playback_quality).toInt();
+        RetrieveYoutubeUrl::setUserAgent(set->value("user_agent", "Mozilla/5.0 (X11; Linux x86_64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1").toString());
+        FontPref::base_size = set->value("font_base_size", FontPref::base_size).toInt();
         set->endGroup();
     }
 
@@ -854,15 +980,32 @@ void YTDialog::loadConfig()
 #ifdef PORTABLE_APP
         recording_dialog->setRecordingsDirectory(qApp->applicationDirPath());
 #else
-        QString mdir = QDesktopServices::storageLocation(QDesktopServices::MoviesLocation);
+ #ifdef Q_WS_AMIGA // zzd10h
+        QDir currentDir ;
+        QString mdir = currentDir.absolutePath() + "/Amiga/Videos";
+        if (!QFile::exists(mdir)) {
+            qWarning("YTDialog::loadConfig: folder '%s' does not exist. Using \"RAM Disk:\" as fallback", mdir.toUtf8().constData());
+            mdir = "/RAM Disk/";
+        }
+        QString default_recording_folder = mdir ;
+ #else
+        QString mdir;
+        #if QT_VERSION >= 0x050000
+        mdir = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation);
+        if (mdir.isEmpty()) mdir = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
+        if (mdir.isEmpty()) mdir = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+        #else
+        mdir = QDesktopServices::storageLocation(QDesktopServices::MoviesLocation);
         if (mdir.isEmpty()) mdir = QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation);
         if (mdir.isEmpty()) mdir = QDesktopServices::storageLocation(QDesktopServices::HomeLocation);
+        #endif
         if (mdir.isEmpty()) mdir = "/tmp";
         if (!QFile::exists(mdir)) {
             qWarning("YTDialog::loadConfig: folder '%s' does not exist. Using /tmp as fallback", mdir.toUtf8().constData());
             mdir = "/tmp";
         }
         QString default_recording_folder = mdir + "/Youtube";
+ #endif
         if (!QFile::exists(default_recording_folder)) {
             qDebug("YTDialog::loadConfig: creating '%s'", default_recording_folder.toUtf8().constData());
             if (!QDir().mkdir(default_recording_folder)) {
@@ -877,16 +1020,32 @@ void YTDialog::loadConfig()
 void YTDialog::saveConfig() 
 {
     if (set) {
-        set->beginGroup("general");
+        set->beginGroup("General");
         set->setValue("recording_directory", recording_dialog->recordingsDirectory());
         set->setValue("record_quality", recording_dialog->recordingQuality());
+        #ifdef USE_PLAYERS
         set->setValue("player", players.current());
+        #endif
         set->setValue("region", api->region());
         set->setValue("period", api->period());
         set->setValue("playback_quality", playback_quality);
+        set->setValue("user_agent", RetrieveYoutubeUrl::userAgent());
+        set->setValue("font_base_size", FontPref::base_size);
         set->endGroup();
         set->sync();
     }
 }
 
+void YTDialog::incFontSize() {
+    qDebug("YTDialog::incFontSize");
+    FontPref::base_size++;
+    updateNextPrevWidget();
+}
+
+void YTDialog::decFontSize() {
+    qDebug("YTDialog::decFontSize");
+    FontPref::base_size--;
+    updateNextPrevWidget();
+}
+
 #include "moc_ytdialog.cpp"
