@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2014 Ricardo Villalba <rvm@users.sourceforge.net>
     Copyright (C) 2010 Ori Rejwan
 
     This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,12 @@
 #include <QToolButton>
 #include <QLineEdit>
 #include <QScrollBar>
+
+#ifdef USE_PLAYERS
 #include "players.h"
+#else
+#include "hcplayer.h"
+#endif
 
 class YTTabBar;
 class YTDelegate;
@@ -140,7 +145,7 @@ public:
 
         Popular,
         Music,
-        Rated
+        Sport
     };
 
     enum Mode
@@ -169,7 +174,7 @@ public:
     int playbackQuality() { return playback_quality; }
 
     void setLoadingOverlay(bool enable);
-    bool eventFilter(QObject *w, QEvent *e);
+    /* bool eventFilter(QObject *w, QEvent *e); */
     void setMode(Mode mode);
     void addTab(Tabs tab);
 
@@ -181,7 +186,9 @@ signals:
     void gotUrls(const QMap<int, QString>&, QString, QString);
 
 public slots:
+#ifdef USE_SINGLE_APPLICATION
     void handleMessage(const QString& message);
+#endif
     void gotCurrentTab(int index);
     void nextClicked();
     void prevClicked();
@@ -189,11 +196,14 @@ public slots:
     void gotPixmap(QPixmap pix, int id);
     void videoClicked(QListWidgetItem* item);
     void videoDblClicked(QListWidgetItem* item);
+    void videoItemChanged(QListWidgetItem * current, QListWidgetItem * previous);
     void setSearchTerm(QString term);
     void showContextMenu(QPoint point);
     void recordItem(QListWidgetItem* item);
+    void recordAudioItem(QListWidgetItem* item);
     void playVideo(QString file);
     void playYTUrl(const QString &url, QString title, QString id);
+    void addToPlaylist(const QString &url);
 
 protected slots:
     void showConfigDialog();
@@ -201,6 +211,9 @@ protected slots:
     void showErrorDialog(const QString & error);
     void showErrorSignatureNotFound(const QString &);
 
+    void incFontSize();
+    void decFontSize();
+
 private:
     YTTabBar* tabBar;
     YTDataAPI* api;
@@ -223,9 +236,12 @@ private:
     QToolButton * recordingButton;
 
     QSettings * set;
-    Players players;
     int playback_quality;
 
+#ifdef USE_PLAYERS
+    Players players;
+#endif
+
 #ifdef YT_USE_SCRIPT
     QString script_file;
 #endif
